@@ -213,7 +213,7 @@ if (~isempty (seeked) && ~isempty (trigger))
   error ('seeked and trigger are mutuallly incompatible arguments');
 endif
 
-indi = 0; 
+indi = 0;
 while (indi <= size (varargin, 2))
   indi = indi + 1;
   if (~isa (x, 'dataframe'))
@@ -221,8 +221,8 @@ while (indi <= size (varargin, 2))
       dummy = tilde_expand (x);
       try
         %# read the data frame from a file
-        x = load (dummy);
         df._src{end+1, 1} = dummy;
+        x = load (dummy);
       catch
         %# try our own method
         UTF8_BOM = char ([0xEF 0xBB 0xBF]);
@@ -256,7 +256,7 @@ while (indi <= size (varargin, 2))
           [fid, msg] = fopen (dummy, 'rt');
         else
           %# The file we read from external process must be seekable !!!
-          tmpfile = tmpnam (); df._src{end+1, 1} = dummy;
+          tmpfile = tmpnam (); 
           %# quote to protect from spaces in the name
           dummy = strcat ('''', dummy, '''');
           cmd = [cmd, dummy,  ' > ',  tmpfile];
